@@ -33,3 +33,8 @@ class UnsliceableShapeError(PolytopeError, KeyError):
     def __init__(self, axis):
         self.axis = axis
         self.message = f"Higher-dimensional shape does not support unsliceable axis {axis.name}."
+
+
+class BadGridError(PolytopeError, ValueError):
+    def __init__(self):
+        self.message = "Data on this grid is not supported by Polytope."
